Learn R Programming

GoodFibes (version 0.1.13)

fibers.smoothed: Smoothing of estimated fiber paths

Description

Applies splines to smooth the stepwise fiber paths produced by good.fibes, with the function ns from splines.

Usage

fibers.smoothed(fib.list, df)

Value

fiber.points

The original fiber path from good.fibes

fiber.smoothed

The curved, smoothed fiber paths

Arguments

fib.list

A list of fibers with $fiber.points, produced by good.fibes or one of the cleaning and processing functions (e.g., fuse.fibers).

df

The degrees of freedom passed to splines2::nsp. Knots equal to df - 1 - intercept are set as breakpoints in the spline curve. A straight line path has a df of 1.

Author

J. Arbour

References

Arbour, J. In Prep. GoodFibes: an R package for the detection of muscle fibers from diceCT scans.

See Also

good.fibes