| fiber.angle | R Documentation |
Calculating the orientation or pennation angle of individual muscle fibers. This function can calculate fiber angles around a central axis (x, y or z) or in reference to a particular "view" (plane). Fiber data can optionally be aligned to a line of action (tendon, line between origin and insertion points, etc.) to calculate pennation angle.
fiber.angle(fib.list, axis, reference = "axis",
endpoints=NULL, end.to.end=FALSE)
fib.list |
A list of muscle fiber paths generated by good.fibes or from the various cleaning and processing function (must contain $fiber.points). |
axis |
The axis around which angles will be calculated as a deviation from. Default is 3 (z). This axis is treated as the "z" axis for "plane" options. |
reference |
Should the orientation angles be calculated about an axis (specified by "axis") or in reference to a plane ("plane.xz" "plane.yz", or "plane.xy", where z is the value of "axis"). When calculating pennation angles, reference = "line.of.action" and argument "endpoints" should be supplied. |
endpoints |
An optional 2X3 matrix generated by |
end.to.end |
Should the angle be calculated over the entire fiber (FALSE) or based on just the enpoints of the fiber (TRUE). |
Fiber angle is calculated from the eigenvectors of a Principal Component Analysis of the fiber coordindates using prcomp.
A vector of angles in degrees corresponding to each fiber in the original list
J. Arbour
Arbour, J. 2023. GoodFibes: an R package for the detection of muscle fibers from diceCT scans. Integrative Organismal Biology 5(1): obad030.
Katzke, J., Puchenkov, P., Stark, H., and Economo, E. 2022. A Roadmap to Reconstructing Muscle Architecture from CT Data. Integrative Organismal Biology 4(1): 1-16.
Sullivan, S., McGechie, F., Middleton, K., and Holliday, C. 3D Muscle Architecture of the Pectoral Muscles of European Starling (Sturnus vulgaris).Integrative Organismal Biology 1(1):1-18.
fiber.lengths
olddir<-getwd()
data(ant.final)
fangle<-fiber.angle(ant.final,3)
fangle
cols<-color.scale(fangle, c("blue", "red"))
muscle.plot.stl(ant.final, cols=cols, df = 1)
setwd(olddir)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.